@@ -4,22 +4,21 @@
 
   Part of the dvipng distribution
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU Lesser General Public License as
+  published by the Free Software Foundation, either version 3 of the
+  License, or (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+  Lesser General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  You should have received a copy of the GNU Lesser General Public
+  License along with this program. If not, see
+  <http://www.gnu.org/licenses/>.
 
-  Copyright (C) 2002-2004 Jan-ke Larsson
+  Copyright (C) 2002-2008 Jan-ke Larsson
 
 ************************************************************************/
 
@@ -62,12 +61,12 @@ void InitVF(struct font_entry * tfontp)
   Message(BE_VERBOSE,"<%s>", tfontp->name);
   if (MmapFile(tfontp->name,&(tfontp->fmmap)))
     Fatal("font file %s unusable", tfontp->name);
-  position=(unsigned char*)tfontp->fmmap.mmap;
+  position=(unsigned char*)tfontp->fmmap.data;
   if (*(position) != PRE) 
-    Fatal("unknown font format in file <%s> !\n",currentfont->name);
+    Fatal("unknown font format in file %s",tfontp->name);
   if (*(position+1) != VF_ID) 
-      Fatal( "wrong version of vf file!  (%d should be 202)\n",
-	     (int)*(position+1));
+      Fatal( "wrong version %d of vf file %s (should be 202)",
+	     (int)*(position+1),tfontp->name);
   DEBUG_PRINT(DEBUG_VF,("\n  VF_PRE:\t'%.*s'", 
 		(int)*(position+2), position+3));
   position = position+3 + *(position+2);
@@ -82,7 +81,7 @@ void InitVF(struct font_entry * tfontp)
   position += 8;
   while(*position >= FNT_DEF1 && *position <= FNT_DEF4) {
     DEBUG_PRINT(DEBUG_VF,("\n  @%ld VF:\t%s", 
-			  (long)position - (long)tfontp->fmmap.mmap, 
+			  (long)position - (long)tfontp->fmmap.data, 
 			  dvi_commands[*position]));
     FontDef(position,tfontp);	
     length = dvi_commandlength[*position];
@@ -98,7 +97,7 @@ void InitVF(struct font_entry * tfontp)
   /* Read char definitions */
   while(*position < FNT_DEF1) {
     DEBUG_PRINT(DEBUG_VF,("\n@%ld VF CHAR:\t", 
-			  (long)position - (long)tfontp->fmmap.mmap));
+			  (long)position - (long)tfontp->fmmap.data));
     tcharptr=xmalloc(sizeof(struct char_entry));
     switch (*position) {
     case LONG_CHAR:
@@ -117,8 +116,8 @@ void InitVF(struct font_entry * tfontp)
     tcharptr->tfmw = (int32_t) 
       ((int64_t) tcharptr->tfmw * tfontp->s / (1 << 20));
     DEBUG_PRINT(DEBUG_VF,(" (%d)",tcharptr->tfmw));
-    if (c > NFNTCHARS) /* Only positive for now */
-      Fatal("vf character exceeds numbering limit");
+    if (c >= NFNTCHARS) /* Only positive for now */
+      Fatal("VF font %s exceeds char numbering limit",tfontp->name);
     tfontp->chr[c] = tcharptr;
     tcharptr->data=position;
     position += tcharptr->length;
